@@ -198,7 +198,6 @@
     dead_code,
     deprecated,
     deprecated_in_future,
-    disjoint_capture_drop_reorder,
     drop_bounds,
     elided_lifetimes_in_paths,
     ellipsis_inclusive_range_patterns,
@@ -299,8 +298,6 @@
         unaligned_references,
     )
 )]
-// beta or stable only lints
-#![cfg_attr(any(beta_lints, stable_lints), deny(safe_packed_borrows))]
 // stable only lints
 #![cfg_attr(
     stable_lints,
@@ -322,6 +319,7 @@
 #![cfg_attr(
     any(nightly_lints, beta_lints),
     deny(
+        rustdoc::bare_urls,
         rustdoc::broken_intra_doc_links,
         rustdoc::invalid_codeblock_attributes,
         rustdoc::invalid_html_tags,
@@ -331,8 +329,6 @@
         rustdoc::private_intra_doc_links,
     )
 )]
-#![cfg_attr(beta_lints, deny(rustdoc::non_autolinks))]
-#![cfg_attr(nightly_lints, deny(rustdoc::bare_urls))]
 
 mod config;
 mod constants;
